@@ -9,7 +9,7 @@ from reV.econ import Econ
 from reV.generation import Gen
 from reV.handlers import Outputs, ExclusionLayers
 from reV.pipeline import Pipeline, Status
-from reV.qa_qc import Summarize, SummaryPlots
+from reV.qa_qc import QaQc
 from reV.rep_profiles import RepProfiles
 from reV.supply_curve import (Aggregation, ExclusionMask,
                               ExclusionMaskFromDict, SupplyCurveAggregation,
